@@ -3,9 +3,11 @@ Main interface for batch service type definitions.
 
 Usage::
 
-    from mypy_boto3.batch.type_defs import ArrayPropertiesDetailTypeDef
+    ```python
+    from mypy_boto3_batch.type_defs import ArrayPropertiesDetailTypeDef
 
     data: ArrayPropertiesDetailTypeDef = {...}
+    ```
 """
 import sys
 from typing import Dict, List
